import wepy from 'wepy';
import global from '../common/global';
import semver from 'semver';

export default class cfgMixin extends wepy.mixin {
  $getShareCfg() {
    let shareArr = wepy.getStorageSync('share_cfg');
    if (shareArr.length > 0) {
      let i = this.$randomNum(0, shareArr.length - 1);
      return shareArr[i];
    } else {
      return {
        str: '怀旧经典游戏',
        image: 'https://resource.kingsome.cn/dalmatian/wapp/share.jpg'
      };
    }
  }
  /*获取成就达成人数要求的配置*/
  $getAchieveShareCfg() {
    let cfgObj = wepy.getStorageSync('cfg');
    let cfgStr = cfgObj.achieve_count;
    let result = [];
    if (cfgStr) {
      try {
        result = JSON.parse(cfgStr);
      } catch (err) {
        console.log('error parse achieve share cfg');
      }
    }
    return result;
  }
  /*帮助视频地址*/
  $getHelpVideoLink() {
    let cfgObj = wepy.getStorageSync('cfg');
    return cfgObj.help_video;
  }
  /*电影播放页面地址*/
  $getMovieUrl() {
    let cfgObj = wepy.getStorageSync('cfg');
    return cfgObj.movieurl;
  }
  $getExtCfg(name) {
    let cfgObj = wepy.getStorageSync('cfg');
    let price = cfgObj.ext_json_cfg;
    let obj = { fc_price: 5, gba_price: 10, ad_price: 3 };
    if (price) {
      try {
        obj = JSON.parse(price);
      } catch (err) {
        console.log('parse json error');
      }
    }
    return obj[name];
  }
  //是否显示vip购买，游戏页面等信息
  $showAll() {
    const cfg = wepy.getStorageSync('cfg');
    let cfgVersion = cfg._serverversion ? cfg._serverversion : '1.0.0';
    cfgVersion = cfgVersion == '-1' ? '1.0.0' : cfgVersion;
    return !semver.gte(global.version, cfgVersion);
  }
  /**
   * 是否显示vip和产品的购买
   * 1. 如果当前版本不低于服务器版本(高于或等于)， 则隐藏所有购买按钮
   * 2. 如果当前版本低于服务器版本
   *    a. 如果当前系统为android，则显示购买
   *    b. ios，则根据ios_buy是否开启，开启的情况下，显示购买。
   *    c. 未开启ios_buy的情况下，如果已有游戏达到show_count, 则也显示购买
   * */
  $showBuy() {
    if (this.$showAll()) {
      if (this.$isIos()) {
        let result = !!this.$getExtCfg('ios_buy');
        if (!result) {
          let count = wepy.getStorageSync('game_count') || 0;
          let countCfg = this.$getExtCfg('show_count') || 0;
          result = count >= countCfg;
        }
        return result;
      } else {
        return true;
      }
    } else {
      return false;
    }
  }
  $showShare() {
    return this.$showAll();
  }
  /**
   * 更新播放位置
   * */
  $updatePlayTime(key, val) {
    let historys = wepy.getStorageSync('mhistory') || [];
    let obj;
    for (let history of historys) {
      if (history.key === key) {
        obj = history;
        break;
      }
    }
    (obj) || (historys.push({key, val}));
    (historys.length > 50) && (historys.shift());
    wepy.setStorageSync('mhistory', historys);
  }
  /**
   * 获取播放位置
   * */
  $getPlayTime(key) {
    let historys = wepy.getStorageSync('mhistory') || [];
    let obj = {key, val: 0}
    for (let history of historys) {
      if (history.key === key) {
        obj = history;
        break;
      }
    }
    return obj.val;
  }
}
